| Title: | Performance Profiles and Nested Performance Profiles |
|---|---|
| Description: | Library to plot performance profiles (Dolan and More (2002) <doi:10.1007/s101070100263>) and nested performance profiles (Hekmati and Mirhajianmoghadam (2019) <doi:10.19139/soic-2310-5070-679>) for a given data frame. |
| Authors: | Brais Gonzalez-Rodriguez [aut, cre] |
| Maintainer: | Brais Gonzalez-Rodriguez <[email protected]> |
| License: | GPL-3 |
| Version: | 0.2.0 |
| Built: | 2026-05-13 05:51:09 UTC |
| Source: | https://github.com/cran/nestedpp |
Function that returns a random data frames
generate_random_example(seed = 1234, nrow = 10, ncol = 5, withNA = TRUE)generate_random_example(seed = 1234, nrow = 10, ncol = 5, withNA = TRUE)
seed |
seed for random generation |
nrow |
number of rows |
ncol |
number of columns |
withNA |
bool to indicate if we want to include some NA values in the data frame |
a data frame with random data
example_data = generate_random_example(seed = 123456, nrow = 15, ncol=6)example_data = generate_random_example(seed = 123456, nrow = 15, ncol=6)
Function to compute the geometric mean
gmean(data, ...)gmean(data, ...)
data |
vector with the data |
... |
further arguments passed to or from other methods |
geometric mean value
gmean(1:10)gmean(1:10)
Function that returns a ggplot object with the corresponding nested performance profile
nested_performance_profile( data, minimize = TRUE, logbase = 1, legend_title = "", best_rule = "winner", xlab = expression(tau), ylab = expression(rho), xmax = 0, colors = c(), plot = TRUE, xgrid = c() )nested_performance_profile( data, minimize = TRUE, logbase = 1, legend_title = "", best_rule = "winner", xlab = expression(tau), ylab = expression(rho), xmax = 0, colors = c(), plot = TRUE, xgrid = c() )
data |
data frame with the data |
minimize |
true if lower values mean best performance and false otherwise |
logbase |
base of the logarithm used to represent nested performance profiles |
legend_title |
title for the legend |
best_rule |
option to choose the best solver eliminated in each iteration ("winner", "mean", "gmean", "median" or custom function) |
xlab |
x axis label |
ylab |
y axis label |
xmax |
maximum value of xaxis |
colors |
vector with the colors of each configuration |
plot |
bool to display the plot or not |
xgrid |
vector for using it as grid in ratios |
ggplot object with the corresponding nested performance profile
example_data = generate_random_example(seed = 1234) nested_performance_profile(example_data)example_data = generate_random_example(seed = 1234) nested_performance_profile(example_data)
Function to compute the number of Na's
number_of_na(data, ...)number_of_na(data, ...)
data |
vector with the data |
... |
further arguments passed to or from other methods |
number of Na's
number_of_na(1:10)number_of_na(1:10)
Function that returns a ggplot object with the corresponding performance profile
performance_profile( data, minimize = TRUE, logbase = 1, legend_title = "", xlab = expression(tau), ylab = expression(rho), xmax = 0, colors = c(), plot = TRUE, xgrid = c() )performance_profile( data, minimize = TRUE, logbase = 1, legend_title = "", xlab = expression(tau), ylab = expression(rho), xmax = 0, colors = c(), plot = TRUE, xgrid = c() )
data |
data frame with the data |
minimize |
true if lower values mean best performance and false otherwise |
logbase |
base of the logarithm used to represent performance profiles |
legend_title |
title for the legend |
xlab |
x axis label |
ylab |
y axis label |
xmax |
maximum value of xaxis |
colors |
vector with the colors of each configuration |
plot |
bool to display the plot or not |
xgrid |
vector for using it as grid in ratios |
ggplot object with the corresponding performance profile
example_data = generate_random_example(seed = 1234) performance_profile(example_data)example_data = generate_random_example(seed = 1234) performance_profile(example_data)
Function to generate a table with different metrics
performance_table(data, tolatex = FALSE)performance_table(data, tolatex = FALSE)
data |
data frame with the data |
tolatex |
true to print the latex code of the table |
the data frame with the metrics
example_data = generate_random_example(seed = 1234) table(example_data)example_data = generate_random_example(seed = 1234) table(example_data)
Function to compute the first quartile
q1(data, ...)q1(data, ...)
data |
vector with the data |
... |
further arguments passed to or from other methods |
1st quartile value
q1(1:10)q1(1:10)
Function to compute the third quartile
q3(data, ...)q3(data, ...)
data |
vector with the data |
... |
further arguments passed to or from other methods |
3st quartile value
q3(1:10)q3(1:10)